# Demos

For now, only directed percolation (DP) in 1d and 2d has been implemented.  A series of related models are in development. We are currently working on extending DP to 3d.

## Directed percolation 

DP model simulations are demonstrated in the following Jupyter notebooks:

- [**1d DP** for a small lattice, to visualize $t$ evolution](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_1d_quick.ipynb)

- [**1d DP** for a large lattice and large number of iterations, to validate $t$-decay of $\overline\rho(t)$ ](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_1d.ipynb)

- [**2d DP** for a large lattice and large number of iterations, to validate $t$-decay of $\overline\rho(t)$ ](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_2d.ipynb)

Related pure-Python demos can be found here:

 - [Python demos](https://github.com/cstarkjp/DPRS/tree/main/demos/)



